Module blaxel.core.client.models.core_event
===========================================

Classes
-------

`CoreEvent(message: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, revision: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, status: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, time: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, type_: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Core event
    
    Attributes:
        message (Union[Unset, str]): Event message
        revision (Union[Unset, str]): RevisionID link to the event
        status (Union[Unset, str]): Event status
        time (Union[Unset, str]): Event time
        type_ (Union[Unset, str]): Event type
    
    Method generated by attrs for class CoreEvent.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `message: blaxel.core.client.types.Unset | str`
    :

    `revision: blaxel.core.client.types.Unset | str`
    :

    `status: blaxel.core.client.types.Unset | str`
    :

    `time: blaxel.core.client.types.Unset | str`
    :

    `type_: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :